/**************************************************************************************************
  Filename:       sample.c
  Revised:        $Date: 2007-01-23 12:23:54 -0700 (Tue, 23 Jan 2007) $
  Revision:       $Revision: 13579 $

  Description:    Describe the purpose and contents of the file.


  Copyright  2007 Texas Instruments Inc.  All rights reserved.

  Texas Instruments licenses to you the right to use, modify, copy, and 
  distribute this Software only when embedded on a Texas Instruments
  microcontroller or other microcontroller that is used with a Texas
  Instruments radio frequency transceiver, which are integrated into
  your product or third party product (pursuant to the sublicense terms
  in the accompanying license agreement).  

  You should refer to the license agreement accompanying this Software
  for additional information regarding your rights and obligations.

  SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS WITHOUT WARRANTY OF
  ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION,
  ANY WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS
  FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS
  LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT, NEGLIGENCE, STRICT
  LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
  THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT
  LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL
  DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF SUBSTITUTE
  GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES (INCLUDING
  BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
**************************************************************************************************/

#ifndef BSP_BUTTON_DEFS_H
#define BSP_BUTTON_DEFS_H


/* ------------------------------------------------------------------------------------------------
 *                                           Includes
 * ------------------------------------------------------------------------------------------------
 */
#include "bsp_board_defs.h"
#include "bsp_macros.h"


/* ------------------------------------------------------------------------------------------------
 *                                      Button Configuration
 * ------------------------------------------------------------------------------------------------
 */
#define __bsp_NUM_BUTTONS__                   1
#define __bsp_BUTTON_DEBOUNCE_WAIT__(expr)    st( int i; for(i=0; i<500; i++) { if (!(expr)) i = 0; } )


/* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *                 BUTTON #1
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *   Schematic   :  TS1
 *   Description :  Push Button
 *   Polarity    :  Active Low
 *   GPIO        :  P1.2
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */
#define __bsp_BUTTON1_BIT__           2
#define __bsp_BUTTON1_PORT__          P1IN
#define __bsp_BUTTON1_IS_ACTIVE_LOW   1


/* extended config : enable a pull-up resistor for button #1 */
#define __bsp_BUTTON_EXTENDED_CONFIG__()  st( P1OUT |= BV( __bsp_BUTTON1_BIT__ ); \
                                              P1REN |= BV( __bsp_BUTTON1_BIT__ ); )


/* ------------------------------------------------------------------------------------------------
 *                                Include Generic Button Macros
 * ------------------------------------------------------------------------------------------------
 */
#include "code/bsp_generic_buttons.h"


/**************************************************************************************************
 */
#endif
