/**************************************************************************************************
  Filename:       sample.c
  Revised:        $Date: 2007-01-23 12:23:54 -0700 (Tue, 23 Jan 2007) $
  Revision:       $Revision: 13579 $

  Description:    Describe the purpose and contents of the file.


  Copyright  2007 Texas Instruments Inc.  All rights reserved.

  Texas Instruments licenses to you the right to use, modify, copy, and 
  distribute this Software only when embedded on a Texas Instruments
  microcontroller or other microcontroller that is used with a Texas
  Instruments radio frequency transceiver, which are integrated into
  your product or third party product (pursuant to the sublicense terms
  in the accompanying license agreement).  

  You should refer to the license agreement accompanying this Software
  for additional information regarding your rights and obligations.

  SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS WITHOUT WARRANTY OF
  ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION,
  ANY WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS
  FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS
  LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT, NEGLIGENCE, STRICT
  LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
  THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT
  LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL
  DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF SUBSTITUTE
  GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES (INCLUDING
  BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
**************************************************************************************************/

#ifndef BSP_CONFIG_H
#define BSP_CONFIG_H


/**************************************************************************************************
 *                                       Configuration                                            *
 **************************************************************************************************
 */

/*
 *  Supported clock speeds : 1, 2, 4, 6, 8, 10, 12, and 16 MHz.
 *  The clock configuration values for 1, 8, 12, 16 MHz are taken from configuration flash
 *  set at the factory and should be the most accurate.
 *
 *  NOTE!  The clock speeds are approximate as they are derived from an internal
 *         digitally controlled oscillator.
 */
#define BSP_CONFIG_CLOCK_MHZ_SELECT     8  /* approximate MHz */

/*
 *  Custom clock configuration is available.  Provide values for BCSCTL1 and DCOCTL as
 *  shown in the example below.  The clock speed itself must be provided too.  Providing
 *  a custom configuration overrides the above selection.
 *
 *  #define BSP_CONFIG_CUSTOM_CLOCK_MHZ         2.1
 *  #define BSP_CONFIG_MSP430_CUSTOM_BCSCTL1    9
 *  #define BSP_CONFIG_MSP430_CUSTOM_DCOCTL     ( 1 << 5 )
 */


/* ------------------------------------------------------------------------------------------------
 *                                Exported Clock Configuration 
 * ------------------------------------------------------------------------------------------------
 */
#if (defined BSP_CONFIG_CUSTOM_CLOCK_MHZ)      || \
    (defined BSP_CONFIG_MSP430_CUSTOM_BCSCTL1) || \
    (defined BSP_CONFIG_MSP430_CUSTOM_DCOCTL)
#define BSP_CONFIG_CLOCK_MHZ        BSP_CONFIG_CUSTOM_CLOCK_MHZ
#define BSP_CONFIG_MSP430_BCSCTL1   BSP_CONFIG_MSP430_CUSTOM_BCSCTL1
#define BSP_CONFIG_MSP430_DCOCTL    BSP_CONFIG_MSP430_CUSTOM_DCOCTL
#else

#if (BSP_CONFIG_CLOCK_MHZ_SELECT == 1)
#define BSP_CONFIG_CLOCK_MHZ        1.0
#define BSP_CONFIG_MSP430_BCSCTL1   CALBC1_1MHZ   /* factory calibrated value from flash */
#define BSP_CONFIG_MSP430_DCOCTL    CALDCO_1MHZ   /* factory calibrated value from flash */
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 2)
#define BSP_CONFIG_CLOCK_MHZ        2.1
#define BSP_CONFIG_MSP430_BCSCTL1   9
#define BSP_CONFIG_MSP430_DCOCTL    ((/* DCO = */ 1 )  << 5 )
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 4)
#define BSP_CONFIG_CLOCK_MHZ        3.9
#define BSP_CONFIG_MSP430_BCSCTL1   10
#define BSP_CONFIG_MSP430_DCOCTL    ((/* DCO = */ 5 )  << 5 )
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 6)
#define BSP_CONFIG_CLOCK_MHZ        6.1
#define BSP_CONFIG_MSP430_BCSCTL1   12
#define BSP_CONFIG_MSP430_DCOCTL    ((/* DCO = */ 4 )  << 5 )
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 8)
#define BSP_CONFIG_CLOCK_MHZ        8.0
#define BSP_CONFIG_MSP430_BCSCTL1   CALBC1_8MHZ   /* factory calibrated value from flash */
#define BSP_CONFIG_MSP430_DCOCTL    CALDCO_8MHZ   /* factory calibrated value from flash */
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 10)
#define BSP_CONFIG_CLOCK_MHZ        10.3
#define BSP_CONFIG_MSP430_BCSCTL1   14
#define BSP_CONFIG_MSP430_DCOCTL    ((/* DCO = */ 2 )  << 5 ) 
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 12)
#define BSP_CONFIG_CLOCK_MHZ        8.0
#define BSP_CONFIG_MSP430_BCSCTL1   CALBC1_12MHZ  /* factory calibrated value from flash */
#define BSP_CONFIG_MSP430_DCOCTL    CALDCO_12MHZ  /* factory calibrated value from flash */
#elif (BSP_CONFIG_CLOCK_MHZ_SELECT == 16)
#define BSP_CONFIG_CLOCK_MHZ        8.0
#define BSP_CONFIG_MSP430_BCSCTL1   CALBC1_16MHZ  /* factory calibrated value from flash */
#define BSP_CONFIG_MSP430_DCOCTL    CALDCO_16MHZ  /* factory calibrated value from flash */
#else
#error "ERROR: Unsupported clock speed.  Custom clock speeds are possible. See comments in code."
#endif

#endif


/**************************************************************************************************
 */
#endif
