/**************************************************************************************************
  Filename:       sample.c
  Revised:        $Date: 2007-07-06 11:19:00 -0700 (Fri, 06 Jul 2007) $
  Revision:       $Revision: 13579 $

  Description:    Describe the purpose and contents of the file.


  Copyright 2004-2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights granted under
  the terms of a software license agreement between the user who downloaded the software,
  his/her employer (which must be your employer) and Texas Instruments Incorporated (the
  "License"). You may not use this Software unless you agree to abide by the terms of the
  License. The License limits your use, and you acknowledge, that the Software may not be
  modified, copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio frequency
  transceiver, which is integrated into your product. Other than for the foregoing purpose,
  you may not use, reproduce, copy, prepare derivative works of, modify, distribute,
  perform, display or sell this Software and/or its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS
  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
  WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
  IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
  THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
  INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST
  DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY
  THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com. 
**************************************************************************************************/

#ifndef MCU_AVR_H
#define MCU_AVR_H


/* ------------------------------------------------------------------------------------------------
 *                                          Defines
 * ------------------------------------------------------------------------------------------------
 */
#define BSP_MCU_AVR


/* ------------------------------------------------------------------------------------------------
 *                                     Compiler Abstraction
 * ------------------------------------------------------------------------------------------------
 */

/* ---------------------- IAR Compiler ---------------------- */
#ifdef __IAR_SYSTEMS_ICC__
#define BSP_COMPILER_IAR
#define ENABLE_BIT_DEFINITIONS  1  /* need to define before including ioavr.h */
#include <ioavr.h>
#include <intrinsics.h>
#define __BSP_ENABLE_INTERRUPTS__()         __enable_interrupt()
#define __BSP_DISABLE_INTERRUPTS__()        __disable_interrupt()
#define __BSP_INTERRUPTS_ARE_ENABLED__()    (SREG & BV( 7 ))

#define __BSP_ISTATE_T__                    unsigned char
#define __BSP_GET_ISTATE__()                __save_interrupt()
#define __BSP_RESTORE_ISTATE__(x)           __restore_interrupt(x)

#define __BSP_QUOTED_PRAGMA__(x)    _Pragma(#x)
#define __BSP_ISR_FUNCTION__(f,v)   __BSP_QUOTED_PRAGMA__(vector=v) __interrupt void f(void); \
                                    __BSP_QUOTED_PRAGMA__(vector=v) __interrupt void f(void)

/* ---------------------- GNU Compiler ---------------------- */
#elif defined __GNUC__
#define BSP_COMPILER_GCC
#include <io.h>
#define __BSP_ENABLE_INTERRUPTS__()         asm("sei")
#define __BSP_DISABLE_INTERRUPTS__()        asm("cli")
#define __BSP_INTERRUPTS_ARE_ENABLED__()    (SREG & BV( 7 ))

#define __BSP_ISTATE_T__                    unsigned char
#define __BSP_GET_ISTATE__()                SREG
#define __BSP_RESTORE_ISTATE__(x)           do { SREG = x; } while(0)

#include <signal.h>
#define __BSP_ISR_FUNCTION__(f,v)           SIGNAL(v); SIGNAL(v)
/* standardize on IAR interrupt naming convention for interrupt vectors */
#define INT0_vect             SIG_INTERRUPT0
#define INT1_vect             SIG_INTERRUPT1
#define INT2_vect             SIG_INTERRUPT2
#define INT3_vect             SIG_INTERRUPT3
#define INT4_vect             SIG_INTERRUPT4
#define INT5_vect             SIG_INTERRUPT5
#define INT6_vect             SIG_INTERRUPT6
#define INT7_vect             SIG_INTERRUPT7
#define TIMER2_COMP_vect      SIG_OUTPUT_COMPARE2
#define TIMER2_OVF_vect       SIG_OVERFLOW2
#define TIMER1_CAPT_vect      SIG_INPUT_CAPTURE1
#define TIMER1_COMPA_vect     SIG_OUTPUT_COMPARE1A
#define TIMER1_COMPB_vect     SIG_OUTPUT_COMPARE1B
#define TIMER1_OVF_vect       SIG_OVERFLOW1
#define TIMER0_COMP_vect      SIG_OUTPUT_COMPARE0
#define TIMER0_OVF_vect       SIG_OVERFLOW0
#define SPI_STC_vect          SIG_SPI
#define USART0_RXC_vect       SIG_UART0_RECV
#define USART0_UDRE_vect      SIG_UART0_DATA
#define USART0_TXC_vect       SIG_UART0_TRANS
#define ADC_vect              SIG_ADC
#define EE_RDY_vect           SIG_EEPROM_READY
#define ANA_COMP_vect         SIG_COMPARATOR
#define TIMER1_COMPC_vect     SIG_OUTPUT_COMPARE1C
#define TIMER3_CAPT_vect      SIG_INPUT_CAPTURE3
#define TIMER3_COMPA_vect     SIG_OUTPUT_COMPARE3A
#define TIMER3_COMPB_vect     SIG_OUTPUT_COMPARE3B
#define TIMER3_COMPC_vect     SIG_OUTPUT_COMPARE3C
#define TIMER3_OVF_vect       SIG_OVERFLOW3
#define USART1_RXC_vect       SIG_UART1_RECV
#define USART1_UDRE_vect      SIG_UART1_DATA
#define USART1_TXC_vect       SIG_UART1_TRANS
#define TWI_vect              SIG_2WIRE_SERIAL
#define SPM_RDY_vect          SIG_SPM_READY

/* ------------------ Unrecognized Compiler ------------------ */
#else
#error "ERROR: Unknown compiler."
#endif


/* ------------------------------------------------------------------------------------------------
 *                                          Common 
 * ------------------------------------------------------------------------------------------------
 */
#define __BSP_LITTLE_ENDIAN__   1
#define __BSP_CODE_MEMSPACE__   /* blank */
#define __BSP_XDATA_MEMSPACE__  /* blank */

typedef   signed char     __bsp_INT8_T__;
typedef   signed short    __bsp_INT16_T__;
typedef   signed long     __bsp_INT32_T__;

typedef   unsigned char   __bsp_UINT8_T__;
typedef   unsigned short  __bsp_UINT16_T__;
typedef   unsigned long   __bsp_UINT32_T__;


/**************************************************************************************************
 */
#endif

