
/**************************************************************************************************
  Filename:       TI_CC_hardware_borad.h
  Revised:        $Date: 2007-07-10 11:21:35 -0700 (Tue, 10 Jul 2007) $
  Revision:       $Revision: 14865 $

  Description:    This file contains definitions specific to the hardware board.
                  Definitions are included here for the CCxx00 non-SPI interface lines only.
                  Board-specific configuration for switches/LEDS/etc should be in HAL, not LHAL.

  Copyright 2004-2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights granted under
  the terms of a software license agreement between the user who downloaded the software,
  his/her employer (which must be your employer) and Texas Instruments Incorporated (the
  "License"). You may not use this Software unless you agree to abide by the terms of the
  License. The License limits your use, and you acknowledge, that the Software may not be
  modified, copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio frequency
  transceiver, which is integrated into your product. Other than for the foregoing purpose,
  you may not use, reproduce, copy, prepare derivative works of, modify, distribute,
  perform, display or sell this Software and/or its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS
  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
  WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
  IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
  THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
  INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST
  DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY
  THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
**************************************************************************************************/


#ifndef TI_CC_HARDWARE_BOARD_H
#define TI_CC_HARDWARE_BOARD_H


#include "TI_CC_msp430.h"

#if defined( EXP )
#define TI_CC_RF_SER_INTF  TI_CC_SER_INTF_USART1

// EXP Board with MSP430FG4618


#define TI_CC_GDO0_PxOUT        P1OUT
#define TI_CC_GDO0_PxIN         P1IN
#define TI_CC_GDO0_PxDIR        P1DIR
#define TI_CC_GDO0_PxIE         P1IE
#define TI_CC_GDO0_PxIES        P1IES
#define TI_CC_GDO0_PxIFG        P1IFG
#define TI_CC_GDO0_PIN          BIT2

// GDO1 (SPI MISO) not used as GPIO pin. Configuration here
// maps it to SOMI on MCU but is redundant
#define TI_CC_GDO1_PxOUT        P4OUT   // Note: GDO1 is output to MCU only
#define TI_CC_GDO1_PxIN         P4IN
#define TI_CC_GDO1_PxDIR        P4DIR
#define TI_CC_GDO1_PIN          BIT4

#define TI_CC_GDO2_PxOUT        P1OUT   // Note: GDO2 is output to MCU only
#define TI_CC_GDO2_PxIN         P1IN
#define TI_CC_GDO2_PxDIR        P1DIR
#define TI_CC_GDO2_PxIE         P1IE
#define TI_CC_GDO2_PxIES        P1IES
#define TI_CC_GDO2_PxIFG        P1IFG
#define TI_CC_GDO2_PIN          BIT3

#define TI_CC_CSn_PxOUT         P4OUT
#define TI_CC_CSn_PxIN          P4IN
#define TI_CC_CSn_PxDIR         P4DIR
#define TI_CC_CSn_PIN           BIT2

#elif defined( EZ430RF )
#define TI_CC_RF_SER_INTF  TI_CC_SER_INTF_USCIB0


#define TI_CC_GDO0_PxOUT        P2OUT
#define TI_CC_GDO0_PxIN         P2IN
#define TI_CC_GDO0_PxDIR        P2DIR
#define TI_CC_GDO0_PxIE         P2IE
#define TI_CC_GDO0_PxIES        P2IES
#define TI_CC_GDO0_PxIFG        P2IFG
#define TI_CC_GDO0_PIN          BIT6


#define TI_CC_GDO1_PxOUT        P3OUT   // Note: GDO1 is output to MCU only
#define TI_CC_GDO1_PxIN         P3IN
#define TI_CC_GDO1_PxDIR        P3DIR
#define TI_CC_GDO1_PIN          BIT2

#define TI_CC_GDO2_PxOUT        P2OUT   // Note: GDO2 is output to MCU only
#define TI_CC_GDO2_PxIN         P2IN
#define TI_CC_GDO2_PxDIR        P2DIR
#define TI_CC_GDO2_PxIE         P2IE
#define TI_CC_GDO2_PxIES        P2IES
#define TI_CC_GDO2_PxIFG        P2IFG
#define TI_CC_GDO2_PIN          BIT7

#define TI_CC_CSn_PxOUT         P3OUT
#define TI_CC_CSn_PxIN          P3IN
#define TI_CC_CSn_PxDIR         P3DIR
#define TI_CC_CSn_PIN           BIT0

#endif

#endif

