
/**************************************************************************************************
  Filename:       TI_CC_msp430.h
  Revised:        $Date: 2007-07-10 11:21:35 -0700 (Tue, 10 Jul 2007) $
  Revision:       $Revision: 14865 $

  Description:    This file contains definitions specific to the specific MSP430
                  chosen for this implementation.  MSP430 has multiple interfaces capable
                  of interfacing to the SPI port; each of these is defined in this file.

  Copyright 2004-2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights granted under
  the terms of a software license agreement between the user who downloaded the software,
  his/her employer (which must be your employer) and Texas Instruments Incorporated (the
  "License"). You may not use this Software unless you agree to abide by the terms of the
  License. The License limits your use, and you acknowledge, that the Software may not be
  modified, copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio frequency
  transceiver, which is integrated into your product. Other than for the foregoing purpose,
  you may not use, reproduce, copy, prepare derivative works of, modify, distribute,
  perform, display or sell this Software and/or its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS
  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
  WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
  IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
  THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
  INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST
  DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY
  THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
**************************************************************************************************/


//    **** MSP430FG4619 ****

#ifndef TI_CC_MSP430_H
#define TI_CC_MSP430_H

//----------------------------------------------------------------------------
//  These constants are used to identify the chosen SPI and UART interfaces.
//----------------------------------------------------------------------------
#define TI_CC_SER_INTF_NULL    0
#define TI_CC_SER_INTF_USART1  2
#define TI_CC_SER_INTF_USCIB0  5

#if defined( EXP )

#include <msp430xG46x.h>                     // Adjust this according to the
                                            // MSP430 device being used.

// SPI port definitions                     // Adjust the values for the chosen
#define TI_CC_SPI_USART1_PxSEL  P4SEL       // interfaces, according to the pin
#define TI_CC_SPI_USART1_PxDIR  P4DIR       // assignments indicated in the
#define TI_CC_SPI_USART1_PxIN   P4IN        // chosen MSP430 device datasheet.
#define TI_CC_SPI_USART1_SIMO   BIT3
#define TI_CC_SPI_USART1_SOMI   BIT4
#define TI_CC_SPI_USART1_UCLK   BIT5

#define TI_CC_SPI_USCIA0_PxSEL  P7SEL
#define TI_CC_SPI_USCIA0_PxDIR  P7DIR
#define TI_CC_SPI_USCIA0_PxIN   P7IN
#define TI_CC_SPI_USCIA0_SIMO   BIT1
#define TI_CC_SPI_USCIA0_SOMI   BIT2
#define TI_CC_SPI_USCIA0_UCLK   BIT3

#define TI_CC_SPI_USCIB0_PxSEL  P3SEL
#define TI_CC_SPI_USCIB0_PxDIR  P3DIR
#define TI_CC_SPI_USCIB0_PxIN   P3IN
#define TI_CC_SPI_USCIB0_SIMO   BIT1
#define TI_CC_SPI_USCIB0_SOMI   BIT2
#define TI_CC_SPI_USCIB0_UCLK   BIT3

#elif defined( EZ430RF )

#include <msp430x22x4.h>

#define TI_CC_SPI_USCIB0_PxSEL  P3SEL
#define TI_CC_SPI_USCIB0_PxDIR  P3DIR
#define TI_CC_SPI_USCIB0_PxIN   P3IN
#define TI_CC_SPI_USCIB0_SIMO   BIT1
#define TI_CC_SPI_USCIB0_SOMI   BIT2
#define TI_CC_SPI_USCIB0_UCLK   BIT3

#else
#error ERROR: No MSP target defined
#endif

#endif
