/**************************************************************************************************
  Filename:       ccrf_regDef.h
  Revised:        $Date: 2007-07-11 17:22:30 -0700 (Wed, 11 Jul 2007) $
  Revision:       $Revision: 14907 $

  Description:    This file contains register configurations for  the CC1100/CC2500
                  family of Chipcon RF chips from Texas Instruments. This output was
                  constructed from the SmartRF04 application.

  Copyright 2004-2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights granted under
  the terms of a software license agreement between the user who downloaded the software,
  his/her employer (which must be your employer) and Texas Instruments Incorporated (the
  "License"). You may not use this Software unless you agree to abide by the terms of the
  License. The License limits your use, and you acknowledge, that the Software may not be
  modified, copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio frequency
  transceiver, which is integrated into your product. Other than for the foregoing purpose,
  you may not use, reproduce, copy, prepare derivative works of, modify, distribute,
  perform, display or sell this Software and/or its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS
  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
  WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
  IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
  THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
  INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST
  DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY
  THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
**************************************************************************************************/


#ifndef CCRF_REGCFG_H
#define CCRF_REGCFG_H



#if TI_CC_RF_FREQ == 868

const ccRadioReg_t CCxxx0Radio[] = {
//  Val   Reg offset
  {0x0F,  TI_CCxxx0_FIFOTHR},    // Rx/Tx FIFO threshold.
  {0x3F,  TI_CCxxx0_MCSM1},      // Main Radio Control State Machine configuration.
  {0x0B,  TI_CCxxx0_FSCTRL1},    // Frequency synthesizer control.
  {0x00,  TI_CCxxx0_FSCTRL0},    // Frequency synthesizer control.
  {0x21,  TI_CCxxx0_FREQ2},      // Frequency control word, high byte.
  {0x62,  TI_CCxxx0_FREQ1},      // Frequency control word, middle byte.
  {0x76,  TI_CCxxx0_FREQ0},      // Frequency control word, low byte.
  {0x2D,  TI_CCxxx0_MDMCFG4},    // Modem configuration.
  {0x3B,  TI_CCxxx0_MDMCFG3},    // Modem configuration.
  {0x73,  TI_CCxxx0_MDMCFG2},    // Modem configuration.
  {0x22,  TI_CCxxx0_MDMCFG1},    // Modem configuration.
  {0xF8,  TI_CCxxx0_MDMCFG0},    // Modem configuration.
  {0x00,  TI_CCxxx0_CHANNR},     // Channel number.
  {0x00,  TI_CCxxx0_DEVIATN},    // Modem deviation setting (when FSK modulation is enabled).
  {0xB6,  TI_CCxxx0_FREND1},     // Front end RX configuration.
  {0x10,  TI_CCxxx0_FREND0},     // Front end RX configuration.
  {0x18,  TI_CCxxx0_MCSM0},      // Main Radio Control State Machine configuration.
  {0x1D,  TI_CCxxx0_FOCCFG},     // Frequency Offset Compensation Configuration.
  {0x1C,  TI_CCxxx0_BSCFG},      // Bit synchronization Configuration.
  {0xC7,  TI_CCxxx0_AGCCTRL2},   // AGC control.
  {0x00,  TI_CCxxx0_AGCCTRL1},   // AGC control.
  {0xB2,  TI_CCxxx0_AGCCTRL0},   // AGC control.
  {0xEA,  TI_CCxxx0_FSCAL3},     // Frequency synthesizer calibration.
  {0x2A,  TI_CCxxx0_FSCAL2},     // Frequency synthesizer calibration.
  {0x00,  TI_CCxxx0_FSCAL1},     // Frequency synthesizer calibration.
  {0x11,  TI_CCxxx0_FSCAL0},     // Frequency synthesizer calibration.
  {0x59,  TI_CCxxx0_FSTEST},     // Frequency synthesizer calibration.
  {0x88,  TI_CCxxx0_TEST2},      // Various test settings.
  {0x31,  TI_CCxxx0_TEST1},      // Various test settings.
  {0x0B,  TI_CCxxx0_TEST0},      // Various test settings.
  {0x0B,  TI_CCxxx0_IOCFG2},     // GDO2 output pin configuration.
  {0x01,  TI_CCxxx0_IOCFG0},     // GDO0 output pin configuration. Refer to SmartRF Studio User Manual for detailed pseudo register explanation.
  {0x0C,  TI_CCxxx0_PKTCTRL1},   // Packet automation control. CRC flush + append
  {0x05,  TI_CCxxx0_PKTCTRL0},   // Packet automation control.
  {0x00,  TI_CCxxx0_ADDR},       // Device address.
  {0x3D,  TI_CCxxx0_PKTLEN}      // Packet length.
};

// PATABLE (0 dBm output power)
const uint8_t myPaTable[]  = {0x8E};  // 0 dBm
const uint8_t myPaTableLen = 1;


#elif TI_CC_RF_FREQ == 2433


const ccRadioReg_t CCxxx0Radio[] = {
//  Val   Reg offset
  {0x0F,  TI_CCxxx0_FIFOTHR},    // Rx/Tx FIFO threshold.
  {0x3F,  TI_CCxxx0_MCSM1},      // Main Radio Control State Machine configuration.
  {0x09,  TI_CCxxx0_FSCTRL1},    // Frequency synthesizer control.
  {0x00,  TI_CCxxx0_FSCTRL0},    // Frequency synthesizer control.
  {0x5D,  TI_CCxxx0_FREQ2},      // Frequency control word, high byte.
  {0x93,  TI_CCxxx0_FREQ1},      // Frequency control word, middle byte.
  {0xB1,  TI_CCxxx0_FREQ0},      // Frequency control word, low byte.
  {0x2D,  TI_CCxxx0_MDMCFG4},    // Modem configuration.
  {0x3B,  TI_CCxxx0_MDMCFG3},    // Modem configuration.
  {0x73,  TI_CCxxx0_MDMCFG2},    // Modem configuration.
  {0x22,  TI_CCxxx0_MDMCFG1},    // Modem configuration.
  {0xF8,  TI_CCxxx0_MDMCFG0},    // Modem configuration.
  {0x00,  TI_CCxxx0_CHANNR},     // Channel number.
  {0x01,  TI_CCxxx0_DEVIATN},    // Modem deviation setting (when FSK modulation is enabled).
  {0xB6,  TI_CCxxx0_FREND1},     // Front end RX configuration.
  {0x10,  TI_CCxxx0_FREND0},     // Front end RX configuration.
  {0x18,  TI_CCxxx0_MCSM0},      // Main Radio Control State Machine configuration.
  {0x1D,  TI_CCxxx0_FOCCFG},     // Frequency Offset Compensation Configuration.
  {0x1C,  TI_CCxxx0_BSCFG},      // Bit synchronization Configuration.
  {0xC7,  TI_CCxxx0_AGCCTRL2},   // AGC control.
  {0x00,  TI_CCxxx0_AGCCTRL1},   // AGC control.
  {0xB2,  TI_CCxxx0_AGCCTRL0},   // AGC control.
  {0xEA,  TI_CCxxx0_FSCAL3},     // Frequency synthesizer calibration.
  {0x0A,  TI_CCxxx0_FSCAL2},     // Frequency synthesizer calibration.
  {0x00,  TI_CCxxx0_FSCAL1},     // Frequency synthesizer calibration.
  {0x11,  TI_CCxxx0_FSCAL0},     // Frequency synthesizer calibration.
  {0x59,  TI_CCxxx0_FSTEST},     // Frequency synthesizer calibration.
  {0x88,  TI_CCxxx0_TEST2},      // Various test settings.
  {0x31,  TI_CCxxx0_TEST1},      // Various test settings.
  {0x0B,  TI_CCxxx0_TEST0},      // Various test settings.
  {0x0B,  TI_CCxxx0_IOCFG2},     // GDO2 output pin configuration.
  {0x01,  TI_CCxxx0_IOCFG0},     // GDO0 output pin configuration. Refer to SmartRF Studio User Manual for detailed pseudo register explanation.
  {0x0C,  TI_CCxxx0_PKTCTRL1},   // Packet automation control.  CRC flush + append
  {0x05,  TI_CCxxx0_PKTCTRL0},   // Packet automation control.
  {0x00,  TI_CCxxx0_ADDR},       // Device address.
  {0x3D,  TI_CCxxx0_PKTLEN}      // Packet length.
};

// PATABLE (0 dBm output power)
const uint8_t myPaTable[]  = {0xFB};  // 0 dBm
const uint8_t myPaTableLen = 1;

#else
#error ERROR: No default frequency defined
#endif

#endif
